@@ -60,7 +60,8 @@ def render_asset(name: str, target_path: Path, format_dict: Dict[str, str], enco
         format_dict -- Format asset with values from the dict before writing.
         encoding -- File encoding.
     """
-    content = pkg_resources.files(assets_resource).joinpath(name).read_text()
+    path: Path = pkg_resources.files(assets_resource).joinpath(name)  # type: ignore
+    content = path.read_text()
     content = content.format(**format_dict)
     target_path.write_text(content, encoding=encoding)
 
